<?php

namespace DsbNext\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;

class DashboardTAController{
    
    protected $crudService;
    
    public function __construct($connection, $environment, $util, $crudService) {
        $this->crudService    = $crudService;
        $this->connection      = $connection;
        $this->environment     = $environment;
        $this->util            = $util;
    }
    
    public function previousDayAFDeliveryTA(Request\Filter $request, Response $response) {
        $params = ['CDFILCENTCMP'];
        $conditions = $this->util->prepareConditions($params);
        
        $data = $this->crudService->getFilteredDataSet('previousDayAFDeliveryTA', $conditions)->getRows();
        $response->addDataSet(new DataSet("previousDayAFDeliveryTA", $data));
    }
    
    public function afApprovalTracking(Request\Filter $request, Response $response) {
        $params = ['CDFILCENTCMP'];
        $conditions = $this->util->prepareConditions($params);
        
        $data = $this->crudService->getFilteredDataSet('afApprovalTracking', $conditions)->getRows();
        $response->addDataSet(new DataSet("afApprovalTracking", $data));
    }
    
    public function aFDeliveryLastWeekTA(Request\Filter $request, Response $response) {
        $params = ['CDFILCENTCMP'];
        $conditions = $this->util->prepareConditions($params);
        
        $data = $this->crudService->getFilteredDataSet('aFDeliveryLastWeekTA', $conditions)->getRows();
        $response->addDataSet(new DataSet("aFDeliveryLastWeekTA", $data));
    }
    
    public function aFDeliveryLastWeekGrid(Request\Filter $request, Response $response) {
        $params = ['CDFILCENTCMP'];
        $conditions = $this->util->prepareConditions($params);
        $filter = $request->getFilterCriteria()->getConditions();
        
        $data = $this->crudService->getFilteredDataSet('aFDeliveryLastWeekGrid', array_merge($conditions, $filter))->getRows();
        $response->addDataSet(new DataSet("aFDeliveryLastWeekGrid", $data));
    }
    public function getAFGeneral(Request\Filter $request, Response $response) {
        $params = ['CDFILCENTCMP'];
        $conditions = $this->util->prepareConditions($params);
        $filter = $request->getFilterCriteria()->getConditions();
        
        $data = $this->crudService->getFilteredDataSet('getAFGeneral', array_merge($conditions, $filter))->getRows();
        $response->addDataSet(new DataSet("getAFGeneral", $data));  
    }
    
    public function drillDownAFGeneralFirstLevel($conditions, $idRecebimento, $response) {
        $params = [
                'CDFILCENTCMP' => $conditions[0]['value'],
                'IDCONFRECEBIMENTO' => $idRecebimento
        ];
        $stmt = $this->connection->prepare("
                SELECT 
                    NMOPERADOR AS LABEL,
                    COUNT(NRAUTOFORN) AS VALUE,
                    NVL(IDCONFRECEBIMENTO, 'X') AS IDCONFRECEBIMENTO, 
                    CDOPERADOR
                FROM 
                (
                    SELECT * 
                      FROM DM_TRACKING_AF
                     WHERE CDFILCENTCMP = :CDFILCENTCMP
                       AND DTPROGENTAF BETWEEN TRUNC(FIRST_DAY(SYSDATE)) AND TRUNC(SYSDATE - 1)
                       AND NVL(IDCONFRECEBIMENTO, 'X') = :IDCONFRECEBIMENTO
                )
                GROUP BY 
                    IDCONFRECEBIMENTO,
                    CDOPERADOR,
                    NMOPERADOR
                ORDER BY 
                    CDOPERADOR
            ");
            $stmt->execute($params);
            $result = $stmt->fetchAll();
            
            $response->addDataSet(new DataSet("drillDownAFGeneral", $result));
    }
    
    private function drillDownAFGeneralSecondLevel($conditions, $idRecebimento, $operador, $response){
        $params = array(
            "CDOPERADOR" => $operador,
            "CDFILCENTCMP" => $conditions[0]['value'],
            "IDCONFRECEBIMENTO" => $idRecebimento
        );
        $stmt = $this->connection->prepare("
            SELECT
                NMREGIAOGEO AS LABEL,
                COUNT(NRAUTOFORN) AS VALUE,
                NVL(IDCONFRECEBIMENTO,'X') AS IDCONFRECEBIMENTO,
                CDOPERADOR,
                NMREGIAOGEO AS REGIAO
            FROM
            (
                SELECT * 
                  FROM DM_TRACKING_AF
                 WHERE CDFILCENTCMP = :CDFILCENTCMP
                   AND DTPROGENTAF BETWEEN TRUNC(FIRST_DAY(SYSDATE)) AND TRUNC(SYSDATE - 1)
                   AND CDOPERADOR = :CDOPERADOR
                   AND NVL(IDCONFRECEBIMENTO, 'X') = :IDCONFRECEBIMENTO
            )
            GROUP BY
                NMREGIAOGEO,
                CDOPERADOR,
                IDCONFRECEBIMENTO
            ORDER BY
                NMREGIAOGEO
        ");
        
        $stmt->execute($params);
        $result = $stmt->fetchAll();
        
        $response->addDataSet(new DataSet("drillDownAFGeneral", $result));

    }
    
    public function drillDownAFGeneralThirdLevel($conditions, $idRecebimento, $operador, $regiao, $response) {
         $params = array(
                "NMREGIAOGEO" => $regiao,
                "CDOPERADOR" => $operador,
                "CDFILCENTCMP" => $conditions[0]['value'],
                "IDCONFRECEBIMENTO" => $idRecebimento
                );
            
             $stmt = $this->connection->prepare("
                SELECT
                    NMESTADO AS LABEL,
                    COUNT(NRAUTOFORN) AS VALUE,
                    NVL(IDCONFRECEBIMENTO,'X') AS IDCONFRECEBIMENTO,
                    CDOPERADOR,
                    NMREGIAOGEO AS REGIAO,
                    NMESTADO
                FROM
                (
                    SELECT * 
                      FROM DM_TRACKING_AF
                     WHERE CDFILCENTCMP = :CDFILCENTCMP
                       AND DTPROGENTAF BETWEEN TRUNC(FIRST_DAY(SYSDATE)) AND TRUNC(SYSDATE - 1)
                       AND CDOPERADOR = :CDOPERADOR
                       AND NVL(IDCONFRECEBIMENTO,'X') = :IDCONFRECEBIMENTO
                       AND NMREGIAOGEO = :NMREGIAOGEO
                )
                GROUP BY
                    NMESTADO,
                    NMREGIAOGEO,
                    CDOPERADOR,
                    IDCONFRECEBIMENTO
                ORDER BY
                    NMESTADO
            ");
            
            $stmt->execute($params);
            $result = $stmt->fetchAll();
            
            $response->addDataSet(new DataSet("drillDownAFGeneral", $result));
    }
    
    public function drillDownAFGeneral(Request\Filter $request, Response $response) {
        $data = $request->getParameters();
        $IDCONFRECEBIMENTO = isset($data['IDCONFRECEBIMENTO'])? $data['IDCONFRECEBIMENTO'] : null;
        $CODOPERADOR = isset($data['operador'])? $data['operador']: null;
        $REGIAO = isset($data['regiao'])? $data['regiao'] : null;
        
        
        $params = ['CDFILCENTCMP'];
        $conditions = $this->util->prepareConditions($params);
        $level = $data['level'];
        switch($level){
            case 0:
                $this->drillDownAFGeneralFirstLevel($conditions, $IDCONFRECEBIMENTO, $response);
                break;
            case 1:
                $this->drillDownAFGeneralSecondLevel($conditions, $IDCONFRECEBIMENTO, $CODOPERADOR, $response);
                break;
            case 2:
                $this->drillDownAFGeneralThirdLevel($conditions, $IDCONFRECEBIMENTO, $CODOPERADOR, $REGIAO, $response);
        }
    }
    public function getAFGeneralTAGrid(Request\Filter $request, Response $response) {
        $params = ['CDFILCENTCMP'];
        $parametersArray = [];
        $parameters = $request->getParameters();
        $conditions = $this->util->prepareConditions($params);
        $parametersArrayKeys = array_keys($parameters);
        $filter = $request->getFilterCriteria()->getSearchIn();
        for($i = 0; $i < count($parameters); $i++) {
            if($parametersArrayKeys[$i] != "in" && $parametersArrayKeys[$i] != "order"){
                $parametersArray[] = [
                        "columnName" => $parametersArrayKeys[$i],
                        "operator" => "=",
                        "value" => $parameters[$parametersArrayKeys[$i]]
                ];
            }
            
        }
        $data = $this->crudService->getFilteredDataSet('getAFGeneralTAGrid', array_merge($conditions, $parametersArray))->getRows();
        $response->addDataSet(new DataSet("getAFGeneralTAGridGroup", $data));  
    }
}